[//]: # (**README Improved By ODYSS3EUS**)
[//]: # (Never Underestimate Presentation)
[//]: # (Mae: Professionals have standards)
[//]: # (Koi: Indeed...)
<h1 align="center">
  <br>
  <a href="https://github.com/EpicSans002/aminolib"><img src="https://cdn.discordapp.com/icons/715911730550800514/8b577d0f9d38614422601a71e91b866d.png?size=512" alt="Aminolib" width="200"></a>
  <br>
  Amino.py
  <br>
</h1>

<p align="center">
  <a href="https://discord.gg/2tsJtHccD7"><img src="https://bit.ly/32neyjM"></a>
  <p align="center"> If you have any questions, join us on Discord! </p>
</p>

#### What is this?
Aminolib is an alternate Python API of amino.py with the same function of communicating with Amino's Servers while pretending that you're an App User. This is mostly accomplished by spoofing Device Configuration Headers, while objectifying and organizing Amino Response Data, so that actually doing anything is easier.


#### How do I use this?
Python 3.6 and above is the recommended version for Aminolib.

To install Aminolib, run `python3 -m pip install aminolib`.



[//]: # (*Verbose Instructions For Those Who Want To Start Programming But Don't Know How.)
[//]: # (Mae: Who knows their stuff will do how to do this and who doesn't won't need this. Consider replacing this section entirely.)

[//]: # (PS: This additionally adds more confusion for users, which already created reports of circular imports and more headaches. Pip installs are easier to understand for end users. Pip simplifies everything when dealing with dependencies, updates, installs and removals. Windows Python's default install installs Pip, MOST [not looking at you arch] Distros package python with Pip alongside Python. Who "starting programming" will ever use this?)